#!perl

use Test::More tests => 3;

BEGIN {
    use_ok( 'TV::Humax::Foxsat' ) || print "Bail out!\n";
}

use_ok( 'TV::Humax::Foxsat::hmt_data' );
use_ok( 'TV::Humax::Foxsat::epg_data' );

diag( "Testing TV::Humax::Foxsat $TV::Humax::Foxsat::VERSION, Perl $], $^X" );
